@@ -187,7 +187,10 @@ class Service(object):
             )
             return False
         else:
-            return response.status_code == 200 or response.status_code == 400
+            logger.debug(
+                "Testing url %s returned this status code %s", url, response.status_code
+            )
+            return response.status_code != 404
 
     def _service_is_secured(self):
         """
